Shiny vizsurvey from a R data.frame
Usage
runVizsurvey_from_r(
df,
vars_discretes = NULL,
vars_continuous = NULL,
var_wave = NULL,
var_filter = NULL,
var_intvwr = NULL
)Arguments
- df
data.frame
- vars_discretes
(optional) preset of discretes variables
- var_wave
(optional) name of wave variable. Two variables can be given (c("YEAR","QUARTER")) : the second one is then a second level of wave
- var_filter
(optional) name of filter variable. Two variables can be given : the second one is then a second level of filter
- var_intvwr
(optional) name of interviewer variable
- vars_continous
(optional) preset of continous variables