Used when var_wave (or var_filter) contains more than one variable in the configuration file, for example the year and the quarter. The complete key of a row is then "2024 / T1".
Used when var_wave (or var_filter) contains more than one variable in the configuration file, for example the year and the quarter. The complete key of a row is then "2024 / T1".